***********************************************
****Chapter 1: Review of Linear Regression*****
***********************************************

*** 1.3 Independent samples t test

use http://www.stata-press.com/data/mlmus2/faculty, clear

tabstat salary, by(male) statistics(mean sd n)

graph box salary, over(male) ytitle(Academic salary) asyvars

histogram salary, by(male, rows(2)) xtitle(Academic salary)

generate lsalary = log10(salary)

graph box lsalary, over(male) ytitle(Log academic salary) asyvars

histogram lsalary, by(male, rows(2)) xtitle(Log academic salary)

ttest salary, by(male)
ttest salary, by(male) unequal


*** 1.4 One-way analysis of variance

anova salary male

adjust, by(male)

regress salary market

egen mn_market = mean(market)
generate marketc = market - mn_market

regress salary marketc

predict yhat, xb
twoway (scatter salary market) (line yhat market, sort), ///
   ytitle(Academic salary) xtitle(Marketability)


*** 1.6 Dummy variables

regress salary male
regress salary male, vce(robust)


*** 1.7 Multiple linear regression

tabstat marketc, by(male) statistics(mean sd)

regress salary male marketc
predict yhat2, xb

twoway (scatter salary market if male==1, msymbol(o))    ///
       (line yhat2 market if male==1, sort lpatt(solid)) ///
       (scatter salary market if male==0, msymbol(oh))   ///
       (line yhat2 market if male==0, sort lpatt(dash)), ///
        ytitle(Academic salary) xtitle(Marketability)    ///
       legend(order(1 " " 2 "Men" 3 " " 4 "Women"))

regress salary male marketc yearsdg


*** 1.8 Interactions

generate m_years = male*yearsdg

regress salary male marketc yearsdg m_years

lincom male + m_years*10

twoway (function Women = 36773 + 763.19*x, range(0 41) lpatt(dash)) ///
 (function Men = 36773 + -593.31 + (763.19 + 227.15)*x,             ///
 range(0 41) lpatt(solid)), xtitle(Time since degree (years))       ///
 ytitle(Mean salary)

twoway (function Women =_b[_cons] + _b[yearsdg]*x, range(0 41) lpatt(dash))  ///
 (function Men =_b[_cons] + _b[male] + (_b[yearsdg] + _b[m_years])*x,        ///
 range(0 41) lpatt(solid)), xtitle(Time since degree (years)) ytitle(Mean salary)


*** 1.9 Dummies for more than two groups

generate associate = rank==2 if rank<.
generate full = rank==3 if rank<.

regress salary associate full

lincom _cons + associate
lincom full-associate

xi: regress salary i.rank

anova salary rank

regress salary male marketc yearsdg m_years associate full
testparm associate full

lincom male + m_years*10

*** 1.10 Other types of interactions

generate male_ass = male*associate
generate male_full = male*full

regress salary male marketc yearsdg m_years associate full  ///
   male_ass male_full
testparm male_ass male_full

generate market_yrs = marketc*yearsdg
regress salary male marketc yearsdg m_years associate full ///
   market_yrs


*** 1.11 Nonlinear effects

generate yearsdg2 = yearsdg^2
regress salary male marketc yearsdg m_years associate full ///
   market_yrs yearsdg2

twoway (function Women = _b[_cons] + _b[yearsdg]*x + _b[yearsdg2]*x^2,      ///
         range(0 41) lpatt(dash))                                           ///
       (function Men = _b[_cons] + _b[male] + (_b[yearsdg] + _b[m_years])*x ///
         + _b[yearsdg2]*x^2, range(0 41) lpatt(solid)),                     ///
        xtitle(Time since degree (years)) ytitle(Mean salary)

regress salary male marketc yearsdg m_years associate full ///
   market_yrs yearsdg2 yearsrank


*** 1.12 Residual diagnostics

predict res, residual
histogram res, normal

