*******************************************
****Chapter 11: Crossed random effects*****
*******************************************

*** 11.3 A two-way error-components model

** 11.3.3 Estimation
use http://www.stata-press.com/data/mlmus2/grunfeld, clear

xtmixed I F C || _all: R.fn || yr:, mle  

** 11.3.4 Prediction
predict firm year, reffects
sort fn yr
list fn firmname yr firm year if yr<1938&fn<5, clean noobs

generate reffpart = firm + year
twoway (line reffpart yr, connect(ascending))                                    ///
   (scatter reffpart yr if yr==1954, msymbol(none) mlabel(firmname) mlabpos(3)), ///
   xtitle(Year) ytitle(Predicted random effects of firm and year)                ///
   xscale(range(1935 1958)) legend(off)

twoway line year yr if fn==1, xtitle(Year) ///
  ytitle(Predicted random effect for year)


*** 11.4 How much do primary and secondary schools...

use http://www.stata-press.com/data/mlmus2/fife, clear

egen pick_comb= tag(pid sid)
egen numsid = sum(pick_comb), by(pid)
sort pid sid
list pid sid numsid if pick_comb & pid<10, clean noobs
egen pick_pid = tag(pid)
tabulate numsid if pick_pid

egen numpid = total(pick_comb), by(sid)
egen pick_sid = tag(sid)
tabulate numpid if pick_sid


*** 11.5 An additive crossed random-effects model

** 11.5.2 Estimation using xtmixed
xtmixed attain || _all: R.sid || pid:, mle
estimates store model1


*** 11.6 Including a random interaction

** 11.6.3 Estimation using xtmixed
xtmixed attain || _all: R.sid || pid:, mle
egen comb = group(sid pid)

xtmixed attain || _all: R.sid || pid: || sid:, mle
estimates store model2

lrtest model1 model2

estimates restore model1

** 11.6.4 Some diagnostics
predict secondary primary, reffects

qnorm secondary if pick_sid, xtitle(Quantiles of normal distribution) ///
  ytitle(Quantiles of empirical Bayes predictions)
 
qnorm primary if pick_pid, xtitle(Quantiles of normal distribution) ///
  ytitle(Quantiles of empirical Bayes predictions)


*** 11.7 A trick requiring fewer random effects

ssc install supclust

supclust pid sid, gen(region)

egen num = count(sex), by(sid pid)
drop if num<3
drop region
supclust sid pid, gen(region)
by region sid: generate f = _n==1
by region: generate sec = sum(f)
table sec

xtmixed attain || region: R.sec || pid, mle


*** 11.8 Do salamanders from different populations mate successfully?

use http://www.stata-press.com/data/mlmus2/salamander, clear

table female male if group==1, contents(mean y)


*** 11.9 Crossed random-effects logistic regression

generate m = male - (group-1)*10
generate f = female - (group-1)*10
generate ww = wsf*wsm
xtmelogit y wsm wsf ww || group: R.m || f:, laplace

matrix a = e(b)
xtmelogit y wsm wsf ww || group: R.m || f:, intpoints(2) from(a) ///
  refineopts(iterate(0))

matrix a = e(b)
xtmelogit y wsm wsf ww || group: R.m || f:, intpoints(3) from(a) ///
  refineopts(iterate(0))


lincom _cons, or
lincom _cons + wsf, or
lincom _cons + wsm, or
lincom _cons + wsm + wsf + ww, or

display exp(sqrt(2*(1.10^2+1.16^2))*invnormal(3/4))

